@@ -10,15 +10,15 @@
 
 #include "KBlocksSound.h"
 
-#include <KgSound>
-#include <KgTheme>
+#include <KGameSound>
+#include <KGameTheme>
 
 #include <QStandardPaths>
 
 #include "kblocks_sound_debug.h"
 #include "settings.h"
 
-KBlocksSound::KBlocksSound(const KgTheme *theme)
+KBlocksSound::KBlocksSound(const KGameTheme *theme)
     : SoundInterface()
 {
     loadTheme(theme);
@@ -31,11 +31,11 @@ KBlocksSound::~KBlocksSound()
     delete m_blockRemoveSound;
 }
 
-bool KBlocksSound::loadTheme(const KgTheme *theme)
+bool KBlocksSound::loadTheme(const KGameTheme *theme)
 {
     QString themeMoveSound;
     if (!theme->customData(QStringLiteral("Sound_Block_Move")).isEmpty()) {
-        // TODO: extend KgTheme to provide look-up of relativ path with custom entries
+        // TODO: extend KGameTheme to provide look-up of relativ path with custom entries
         // For now simply searching all possible locations manually, here and below
         themeMoveSound = QStandardPaths::locate(
                     QStandardPaths::AppDataLocation, QLatin1String("themes/") + theme->customData(QStringLiteral("Sound_Block_Move")));
@@ -65,9 +65,9 @@ bool KBlocksSound::loadTheme(const KgTheme *theme)
     delete m_blockFallSound;
     delete m_blockMoveSound;
     delete m_blockRemoveSound;
-    m_blockFallSound = new KgSound(themeFallSound);
-    m_blockMoveSound = new KgSound(themeMoveSound);
-    m_blockRemoveSound = new KgSound(themeRemoveSound);
+    m_blockFallSound = new KGameSound(themeFallSound);
+    m_blockMoveSound = new KGameSound(themeMoveSound);
+    m_blockRemoveSound = new KGameSound(themeRemoveSound);
     return true;
 }
 
